from trim import TrimLLM
from dotenv import load_dotenv

load_dotenv()  # load OPENAI_API_KEY to the environment

# Instantiate the TrimLLM
llm = TrimLLM()

# Prepare your prompt
prompt = "Explain quantum computing in less than 20 words."

# Call the LLM (this uses the _call method internally)
result = llm.invoke(prompt)

print(result)
