from setuptools import setup, find_packages

setup(
    name="trim-sdk",  # The name of your SDK/package
    version="0.2.2",  # I   nitial version
    packages=find_packages(),  # Automatically find all packages/folders
    install_requires=[
        "openai==1.93.0",
        "python-dotenv==1.1.1",
        "langchain-core==0.3.67",
        "langchain-openai==0.3.27",
        "requests>=2.31.0",
        "pydantic>=2.0.0",
    ],
    author="Elad Ben-Zaken",
    description="Trim SDK.",
    long_description=open("README.md").read(),
    long_description_content_type="text/markdown",
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires=">=3.10",
)
