from trim import TrimChatModel
from dotenv import load_dotenv

load_dotenv() # load OPENAI_API_KEY to the environment

# Instantiate the TrimChatModel router LLM
llm = TrimChatModel()

# invocation
response = llm.invoke(
    [
        {"role": "user", "content": "Tell me about Elon Musk in 20 words"}
    ]
)

print(response.content)
